/// <reference types="node" />
import BigNum from '@liskhq/bignum';
import { transactions } from 'lisk-sdk';
import { BaseTransaction } from './legacy_base_transaction';
export interface VoteAsset {
    recipientId: string;
    readonly amount: BigNum;
    readonly votes: ReadonlyArray<string>;
}
export interface CreateVoteAssetInput {
    readonly unvotes?: ReadonlyArray<string>;
    readonly votes?: ReadonlyArray<string>;
}
export declare const voteAssetFormatSchema: {
    type: string;
    required: string[];
    properties: {
        recipientId: {
            type: string;
            format: string;
        };
        amount: {
            type: string;
            format: string;
        };
        votes: {
            type: string;
            minItems: number;
            maxItems: number;
            items: {
                type: string;
                format: string;
            };
            uniqueSignedPublicKeys: boolean;
        };
    };
};
export declare class VoteTransaction extends BaseTransaction {
    readonly containsUniqueData: boolean;
    readonly asset: VoteAsset;
    static TYPE: number;
    static FEE: string;
    constructor(rawTransaction: unknown);
    assetToJSON(): object;
    sign(passphrase: string, secondPassphrase?: string): void;
    protected getBasicBytes(): Buffer;
    prepare(store: transactions.StateStorePrepare): Promise<void>;
    protected verifyAgainstTransactions(transactions: ReadonlyArray<transactions.TransactionJSON>): ReadonlyArray<transactions.TransactionError>;
    protected validateAsset(): ReadonlyArray<transactions.TransactionError>;
    protected applyAsset(store: transactions.StateStore): ReadonlyArray<transactions.TransactionError>;
    protected undoAsset(store: transactions.StateStore): ReadonlyArray<transactions.TransactionError>;
}
