/// <reference types="node" />
import { transactions } from 'lisk-sdk';
import { BaseTransaction, MultisignatureStatus } from './legacy_base_transaction';
export declare const multisignatureAssetFormatSchema: {
    type: string;
    required: string[];
    properties: {
        min: {
            type: string;
            minimum: number;
            maximum: number;
        };
        lifetime: {
            type: string;
            minimum: number;
            maximum: number;
        };
        keysgroup: {
            type: string;
            uniqueItems: boolean;
            minItems: number;
            maxItems: number;
            items: {
                type: string;
                format: string;
            };
        };
    };
};
export interface MultiSignatureAsset {
    readonly keysgroup: ReadonlyArray<string>;
    readonly lifetime: number;
    readonly min: number;
}
export declare class MultisignatureTransaction extends BaseTransaction {
    readonly asset: MultiSignatureAsset;
    static TYPE: number;
    static FEE: string;
    protected _multisignatureStatus: MultisignatureStatus;
    constructor(rawTransaction: unknown);
    protected assetToBytes(): Buffer;
    prepare(store: transactions.StateStorePrepare): Promise<void>;
    protected verifyAgainstTransactions(transactions: ReadonlyArray<transactions.TransactionJSON>): ReadonlyArray<transactions.TransactionError>;
    protected validateAsset(): ReadonlyArray<transactions.TransactionError>;
    processMultisignatures(_: transactions.StateStore): transactions.TransactionResponse;
    protected applyAsset(store: transactions.StateStore): ReadonlyArray<transactions.TransactionError>;
    protected undoAsset(store: transactions.StateStore): ReadonlyArray<transactions.TransactionError>;
    addMultisignature(store: transactions.StateStore, signatureObject: transactions.SignatureObject): transactions.TransactionResponse;
}
