/// <reference types="node" />
import BigNum from '@liskhq/bignum';
import { transactions } from 'lisk-sdk';
export interface StateStoreGetter<T> {
    get(key: string): T;
    find(func: (item: T) => boolean): T | undefined;
}
export interface StateStoreDefaultGetter<T> {
    getOrDefault(key: string): T;
}
export interface StateStoreSetter<T> {
    set(key: string, value: T): void;
}
export interface StateStore {
    readonly account: StateStoreGetter<transactions.Account> & StateStoreDefaultGetter<transactions.Account> & StateStoreSetter<transactions.Account>;
    readonly transaction: StateStoreGetter<transactions.TransactionJSON>;
}
export interface StateStoreCache<T> {
    cache(filterArray: ReadonlyArray<{
        readonly [key: string]: string;
    }>): Promise<ReadonlyArray<T>>;
}
export interface StateStorePrepare {
    readonly account: StateStoreCache<transactions.Account>;
    readonly transaction: StateStoreCache<transactions.TransactionJSON>;
}
export declare enum MultisignatureStatus {
    UNKNOWN = 0,
    NONMULTISIGNATURE = 1,
    PENDING = 2,
    READY = 3,
    FAIL = 4
}
export declare const ENTITY_ACCOUNT = "account";
export declare const ENTITY_TRANSACTION = "transaction";
export declare abstract class BaseTransaction {
    readonly blockId?: string;
    readonly height?: number;
    readonly confirmations?: number;
    readonly signatures: string[];
    readonly timestamp: number;
    readonly type: number;
    readonly containsUniqueData?: boolean;
    readonly asset: object;
    fee: BigNum;
    receivedAt?: Date;
    static TYPE: number;
    static FEE: string;
    protected _id?: string;
    protected _senderPublicKey?: string;
    protected _signature?: string;
    protected _signSignature?: string;
    protected _multisignatureStatus: MultisignatureStatus;
    protected abstract validateAsset(): ReadonlyArray<transactions.TransactionError>;
    protected abstract applyAsset(store: StateStore): ReadonlyArray<transactions.TransactionError>;
    protected abstract undoAsset(store: StateStore): ReadonlyArray<transactions.TransactionError>;
    constructor(rawTransaction: unknown);
    get id(): string;
    get senderId(): string;
    get senderPublicKey(): string;
    get signature(): string;
    get signSignature(): string | undefined;
    toJSON(): transactions.TransactionJSON;
    stringify(): string;
    isReady(): boolean;
    getBytes(): Buffer;
    validate(): transactions.TransactionResponse;
    protected verifyAgainstTransactions(_: ReadonlyArray<transactions.TransactionJSON>): ReadonlyArray<transactions.TransactionError>;
    verifyAgainstOtherTransactions(transactions: ReadonlyArray<transactions.TransactionJSON>): transactions.TransactionResponse;
    apply(store: StateStore): transactions.TransactionResponse;
    undo(store: StateStore): transactions.TransactionResponse;
    prepare(store: StateStorePrepare): Promise<void>;
    addMultisignature(store: StateStore, signatureObject: transactions.SignatureObject): transactions.TransactionResponse;
    addVerifiedMultisignature(signature: string): transactions.TransactionResponse;
    processMultisignatures(store: StateStore): transactions.TransactionResponse;
    isExpired(date?: Date): boolean;
    sign(passphrase: string, secondPassphrase?: string): void;
    protected getBasicBytes(): Buffer;
    assetToJSON(): object;
    protected assetToBytes(): Buffer;
    private _verify;
    private _validateSchema;
}
