"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const lisk_validator_1 = require("@liskhq/lisk-validator");
const _10_delegate_transaction_1 = require("./10_delegate_transaction");
const constants_1 = require("./constants");
const utils_1 = require("./utils");
const validateInputs = ({ username, networkIdentifier, }) => {
    if (!username || typeof username !== 'string') {
        throw new Error('Please provide a username. Expected string.');
    }
    if (username.length > constants_1.USERNAME_MAX_LENGTH) {
        throw new Error(`Username length does not match requirements. Expected to be no more than ${constants_1.USERNAME_MAX_LENGTH} characters.`);
    }
    lisk_validator_1.validateNetworkIdentifier(networkIdentifier);
};
exports.registerDelegate = (inputs) => {
    validateInputs(inputs);
    const { username, passphrase, secondPassphrase, networkIdentifier } = inputs;
    const transaction = {
        ...utils_1.createBaseTransaction(inputs),
        type: 10,
        fee: constants_1.DELEGATE_FEE.toString(),
        asset: { username },
        networkIdentifier,
    };
    if (!passphrase) {
        return transaction;
    }
    const delegateTransaction = new _10_delegate_transaction_1.DelegateTransaction(transaction);
    delegateTransaction.sign(passphrase, secondPassphrase);
    return delegateTransaction.toJSON();
};
//# sourceMappingURL=register_delegate.js.map