"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const lisk_cryptography_1 = require("@liskhq/lisk-cryptography");
const lisk_validator_1 = require("@liskhq/lisk-validator");
const _9_second_signature_transaction_1 = require("./9_second_signature_transaction");
const utils_1 = require("./utils");
const validateInputs = ({ secondPassphrase, networkIdentifier, }) => {
    if (typeof secondPassphrase !== 'string') {
        throw new Error('Please provide a secondPassphrase. Expected string.');
    }
    lisk_validator_1.validateNetworkIdentifier(networkIdentifier);
};
exports.registerSecondPassphrase = (inputs) => {
    validateInputs(inputs);
    const { passphrase, secondPassphrase, networkIdentifier } = inputs;
    const { publicKey } = lisk_cryptography_1.getKeys(secondPassphrase);
    const transaction = {
        ...utils_1.createBaseTransaction(inputs),
        type: 9,
        asset: { publicKey },
        networkIdentifier,
    };
    if (!passphrase) {
        return transaction;
    }
    const secondSignatureTransaction = new _9_second_signature_transaction_1.SecondSignatureTransaction(transaction);
    secondSignatureTransaction.sign(passphrase);
    return secondSignatureTransaction.toJSON();
};
//# sourceMappingURL=register_second_passphrase.js.map