"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const lisk_transactions_1 = require("@liskhq/lisk-transactions");
const command_1 = require("@oclif/command");
const base_1 = tslib_1.__importDefault(require("../../../base"));
const error_1 = require("../../../utils/error");
const flags_1 = require("../../../utils/flags");
const input_1 = require("../../../utils/input");
const network_identifier_1 = require("../../../utils/network_identifier");
exports.processInputs = (networkIdentifier) => ({ passphrase, secondPassphrase, }) => {
    if (!secondPassphrase) {
        throw new error_1.ValidationError('No second passphrase was provided.');
    }
    return lisk_transactions_1.registerSecondPassphrase({
        networkIdentifier,
        passphrase,
        secondPassphrase,
    });
};
class SecondPassphraseCommand extends base_1.default {
    async run() {
        const { flags: { networkIdentifier: networkIdentifierSource, passphrase: passphraseSource, 'second-passphrase': secondPassphraseSource, 'no-signature': noSignature, }, } = this.parse(SecondPassphraseCommand);
        const networkIdentifier = network_identifier_1.getNetworkIdentifierWithInput(networkIdentifierSource, this.userConfig.api.network);
        const processFunction = exports.processInputs(networkIdentifier);
        const inputs = noSignature
            ? await input_1.getInputsFromSources({
                passphrase: undefined,
                secondPassphrase: {
                    source: secondPassphraseSource,
                    repeatPrompt: true,
                },
            })
            : await input_1.getInputsFromSources({
                passphrase: {
                    source: passphraseSource,
                    repeatPrompt: true,
                },
                secondPassphrase: {
                    source: secondPassphraseSource,
                    repeatPrompt: true,
                },
            });
        const result = processFunction(inputs);
        this.print(result);
    }
}
exports.default = SecondPassphraseCommand;
SecondPassphraseCommand.description = `
	Creates a transaction which will register a second passphrase for the account if broadcast to the network.
	`;
SecondPassphraseCommand.examples = ['transaction:create:second-passphrase'];
SecondPassphraseCommand.flags = {
    ...base_1.default.flags,
    networkIdentifier: command_1.flags.string(flags_1.flags.networkIdentifier),
    passphrase: command_1.flags.string(flags_1.flags.passphrase),
    'second-passphrase': command_1.flags.string(flags_1.flags.secondPassphrase),
    'no-signature': command_1.flags.boolean(flags_1.flags.noSignature),
};
//# sourceMappingURL=second-passphrase.js.map