"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const lisk_transactions_1 = require("@liskhq/lisk-transactions");
const lisk_validator_1 = require("@liskhq/lisk-validator");
const command_1 = require("@oclif/command");
const base_1 = tslib_1.__importDefault(require("../../../base"));
const flags_1 = require("../../../utils/flags");
const input_1 = require("../../../utils/input");
const network_identifier_1 = require("../../../utils/network_identifier");
const dataFlag = {
    char: 'd',
    description: `Optional UTF8 encoded data (maximum of 64 bytes) to include in the transaction asset.
	Examples:
	- --data=customInformation
`,
};
const processInputs = (networkIdentifier, amount, address, data) => ({ passphrase, secondPassphrase }) => lisk_transactions_1.transfer({
    networkIdentifier,
    recipientId: address,
    amount,
    data,
    passphrase,
    secondPassphrase,
});
class TransferCommand extends base_1.default {
    async run() {
        const { args, flags: { networkIdentifier: networkIdentifierSource, passphrase: passphraseSource, 'second-passphrase': secondPassphraseSource, 'no-signature': noSignature, data: dataString, }, } = this.parse(TransferCommand);
        const { amount, address } = args;
        const networkIdentifier = network_identifier_1.getNetworkIdentifierWithInput(networkIdentifierSource, this.userConfig.api.network);
        lisk_validator_1.validateAddress(address);
        const normalizedAmount = lisk_transactions_1.utils.convertLSKToBeddows(amount);
        const processFunction = processInputs(networkIdentifier, normalizedAmount, address, dataString);
        if (noSignature) {
            const noSignatureResult = processFunction({
                passphrase: undefined,
                secondPassphrase: undefined,
            });
            this.print(noSignatureResult);
            return;
        }
        const inputs = await input_1.getInputsFromSources({
            passphrase: {
                source: passphraseSource,
                repeatPrompt: true,
            },
            secondPassphrase: !secondPassphraseSource
                ? undefined
                : {
                    source: secondPassphraseSource,
                    repeatPrompt: true,
                },
        });
        const result = processFunction(inputs);
        this.print(result);
    }
}
exports.default = TransferCommand;
TransferCommand.args = [
    {
        name: 'amount',
        required: true,
        description: 'Amount of LSK to send.',
    },
    {
        name: 'address',
        required: true,
        description: 'Address of the recipient.',
    },
];
TransferCommand.description = `
	Creates a transaction which will transfer the specified amount to an address if broadcast to the network.
		`;
TransferCommand.examples = ['transaction:create:transfer 100 13356260975429434553L'];
TransferCommand.flags = {
    ...base_1.default.flags,
    networkIdentifier: command_1.flags.string(flags_1.flags.networkIdentifier),
    passphrase: command_1.flags.string(flags_1.flags.passphrase),
    'second-passphrase': command_1.flags.string(flags_1.flags.secondPassphrase),
    'no-signature': command_1.flags.boolean(flags_1.flags.noSignature),
    data: command_1.flags.string(dataFlag),
};
//# sourceMappingURL=transfer.js.map