"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const lisk_transactions_1 = require("@liskhq/lisk-transactions");
const error_1 = require("./error");
exports.parseTransactionString = (transactionStr) => {
    try {
        return JSON.parse(transactionStr);
    }
    catch (error) {
        throw new error_1.ValidationError('Could not parse transaction JSON.');
    }
};
const defaultTransactions = {
    8: lisk_transactions_1.TransferTransaction,
    9: lisk_transactions_1.SecondSignatureTransaction,
    10: lisk_transactions_1.DelegateTransaction,
    11: lisk_transactions_1.VoteTransaction,
    12: lisk_transactions_1.MultisignatureTransaction,
};
exports.instantiateTransaction = (data) => {
    if (data.type === undefined || data.type === null) {
        throw new Error('Invalid transaction without type');
    }
    if (!Object.keys(defaultTransactions).includes(String(data.type))) {
        throw new Error(`Transaction type ${data.type} is not supported`);
    }
    const TransactionClass = defaultTransactions[data.type];
    return new TransactionClass(data);
};
//# sourceMappingURL=transactions.js.map