/// <reference types="node" />
import * as BigNum from '@liskhq/bignum';
import { BaseTransaction, StateStore, StateStorePrepare } from './base_transaction';
import { TransactionError } from './errors';
export interface TransferAsset {
    readonly data?: string;
    readonly recipientId: string;
    readonly amount: BigNum;
}
export declare const transferAssetFormatSchema: {
    type: string;
    required: string[];
    properties: {
        recipientId: {
            type: string;
            format: string;
        };
        amount: {
            type: string;
            format: string;
        };
        data: {
            type: string;
            format: string;
            maxLength: number;
        };
    };
};
export declare class TransferTransaction extends BaseTransaction {
    readonly asset: TransferAsset;
    static TYPE: number;
    static FEE: string;
    constructor(rawTransaction: unknown);
    protected assetToBytes(): Buffer;
    assetToJSON(): object;
    prepare(store: StateStorePrepare): Promise<void>;
    protected validateAsset(): ReadonlyArray<TransactionError>;
    protected applyAsset(store: StateStore): ReadonlyArray<TransactionError>;
    protected undoAsset(store: StateStore): ReadonlyArray<TransactionError>;
}
